predict.neurona: Predict neurona object
Description
Calculates neurona model predictions for new data.
Usage
# S3 method for neurona
predict(object, newdata, ...)
Arguments
- object
An object model from mia an object class 'neurona'
- newdata
matrix containing dependent variable in the model, wich the predictions are calculated.